@@ -136,16 +136,56 @@ def list_servers(CONF):
 
 # Like below, but for internal use, without print...
 def _list_conn(CONF):
-    lines = send_command_to_haproxy(CONF, f"show servers conn {CONF.backend} \n").split("\n")
-    connections_index = (
-        lines[0].split(" ").index("used_cur")
-    )  # Current connections column index
-    for line in lines[1:]:
-        fields = line.split(" ")
-        if len(fields) > connections_index:
-            if fields[0].startswith(CONF.backend + "/" + CONF.server):
-                current_connections = int(fields[connections_index - 1])
-    return current_connections
+    if not hasattr(CONF, 'backend') or not CONF.backend:
+        raise ValueError("CONF.backend is required")
+    if not hasattr(CONF, 'server') or not CONF.server:
+        raise ValueError("CONF.server is required")
+
+    command = f"show servers conn {CONF.backend}"
+    response = send_command_to_haproxy(CONF, command + "\n")
+    lines = response.strip().splitlines()
+
+    # Return 0 if no output
+    if not lines:
+        return 0
+
+    # Find header line (starts with #)
+    header = None
+    for line in lines:
+        if line.strip().startswith('#'):
+            header = line.strip()
+            break
+    if not header:
+        # No header found → can't parse
+        return 0
+
+    # Parse header: skip comment marker '#', split, and find 'used_cur'
+    try:
+        header_fields = header.lstrip('#').strip().split()
+        if 'used_cur' not in header_fields:
+            return 0  # Column not present
+        connections_index = header_fields.index('used_cur')
+    except Exception:
+        return 0
+
+    # Target server ID: backend/server
+    target = f"{CONF.backend}/{CONF.server}"
+
+    # Iterate over data lines (non-comment)
+    for line in lines:
+        if line.strip().startswith('#'):
+            continue  # Skip comments
+        fields = line.split()
+        if len(fields) <= connections_index:
+            continue  # Not enough columns
+        if fields[0] == target:
+            try:
+                return int(fields[connections_index])
+            except (ValueError, IndexError):
+                return 0
+
+    # If server not found, assume 0 connections
+    return 0
 
 def list_connections(CONF):
     if CONF.verbose:
@@ -231,7 +271,7 @@ def reload_haproxy(CONF):
     if os.popen("systemctl is-active haproxy").read().replace("\n", "") != "active":
         raise Exception("Haproxy service not active.")
     uptime = (
-        os.popen('systemctl status haproxy | grep -Po ".*; \K(.*)(?= ago)"')
+        os.popen(r'systemctl status haproxy | grep -Po ".*; \K(.*)(?= ago)"')
         .read()
         .replace("\n", "")
     )
